import uuid
from django.contrib.auth.models import User
from django.test import TestCase
from django.test.client import Client


class DjangoAdminTest(TestCase):

    def setUp(self):

        pwd = uuid.uuid4().hex
        user = User.objects.create_superuser('admin', 'admin@test.com', pwd)

        client = Client()
        client.login(username=user.username, password=pwd)

        self.client = client

    def test_django_admin(self):

        resp = self.client.get('/admin/trixtest/post/add/')

        self.assertContains(resp, '/static/trix/trix.css')
        self.assertContains(resp, '/static/trix/trix.js')
        self.assertContains(resp, '/static/trix/trix-django.js')

        self.assertContains(resp, '<trix-editor')


class TemplateTest(TestCase):

    def test_template(self):

        resp = self.client.get('/')

        self.assertContains(resp, '/static/trix/trix.css')
        self.assertContains(resp, '/static/trix/trix.js')
        self.assertContains(resp, '/static/trix/trix-django.js')

        self.assertContains(resp, '<trix-editor')



from __future__ import unicode_literals
from django import forms
from django.contrib.admin import widgets as admin_widgets


class TrixEditor(forms.Textarea):

    def render(self, name, value, attrs=None):

        if attrs is None:
            attrs = {}
        attrs.update({'style': 'visibility: hidden; position: absolute;'})

        params = {
            'input': attrs.get('id') or '{}_id'.format(name),
            'class': 'trix-content',
        }
        param_str = ' '.join('{}="{}"'.format(k, v) for k, v in params.items())

        html = super(TrixEditor, self).render(name, value, attrs)
        html += '<p><trix-editor {}></trix-editor></p>'.format(param_str)
        return html

    class Media:
        css = {'all': ('trix/trix.css',)}
        js = ('trix/trix.js', 'trix/trix-django.js')
